# EDABox
Gain Insight into Datasets

---
[![PyPI Latest Release](https://img.shields.io/pypi/v/edabox.svg)](https://pypi.org/project/edabox/)
[![License](https://img.shields.io/pypi/l/pandas.svg)](https://github.com/poushalimukherjee/edabox/blob/main/LICENSE)

### Installation
- [PyPI Link](https://pypi.org/project/edabox/)
  > ```pip install edabox==1.0.0```
- [TestPyPI Link](https://test.pypi.org/project/edabox/)
  > ```pip install -i https://test.pypi.org/simple/ edabox==1.0.0```

---  

### [Documentation](https://edabox.tiiny.site/)


### 
Version: 1.0.2.1 : make syntax backward compatible with Python version < 3.10
